@@ -26,4 +26,5 @@
 # settings
 # 
 
-cat "$1" | gunzip | groff -t -m man -Tascii -rLL=$2n -rLT=$2n | col -bx | vim -R -S $3 -
+escape=$(echo -e '\033')
+cat "$1" | gunzip | groff -t -c -m man -Tascii -rLL=$2n -rLT=$2n | sed "s/$escape\[[^m]*m//g" | col -x -b | vim -R -S $3 -
